# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-s390.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'core-s390.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63ore-s390.proto\x1a\nopts.proto\"~\n\x14user_s390_regs_entry\x12\x10\n\x08psw_mask\x18\x01 \x02(\x04\x12\x10\n\x08psw_addr\x18\x02 \x02(\x04\x12\x0c\n\x04gprs\x18\x03 \x03(\x04\x12\x0c\n\x04\x61\x63rs\x18\x04 \x03(\r\x12\x11\n\torig_gpr2\x18\x05 \x02(\x04\x12\x13\n\x0bsystem_call\x18\x06 \x02(\r\"(\n\x18user_s390_vxrs_low_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\")\n\x19user_s390_vxrs_high_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\"3\n\x16user_s390_fpregs_entry\x12\x0b\n\x03\x66pc\x18\x01 \x02(\r\x12\x0c\n\x04\x66prs\x18\x02 \x03(\x04\"%\n\x15user_s390_gs_cb_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\"1\n\x12user_s390_ri_entry\x12\r\n\x05ri_on\x18\x01 \x02(\r\x12\x0c\n\x04regs\x18\x02 \x03(\x04\"\x80\x03\n\x10thread_info_s390\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12,\n\x06gpregs\x18\x02 \x02(\x0b\x32\x15.user_s390_regs_entryB\x05\xd2?\x02\x08\x01\x12.\n\x06\x66pregs\x18\x03 \x02(\x0b\x32\x17.user_s390_fpregs_entryB\x05\xd2?\x02\x08\x01\x12\x32\n\x08vxrs_low\x18\x04 \x01(\x0b\x32\x19.user_s390_vxrs_low_entryB\x05\xd2?\x02\x08\x01\x12\x34\n\tvxrs_high\x18\x05 \x01(\x0b\x32\x1a.user_s390_vxrs_high_entryB\x05\xd2?\x02\x08\x01\x12,\n\x05gs_cb\x18\x06 \x01(\x0b\x32\x16.user_s390_gs_cb_entryB\x05\xd2?\x02\x08\x01\x12,\n\x05gs_bc\x18\x07 \x01(\x0b\x32\x16.user_s390_gs_cb_entryB\x05\xd2?\x02\x08\x01\x12)\n\x05ri_cb\x18\x08 \x01(\x0b\x32\x13.user_s390_ri_entryB\x05\xd2?\x02\x08\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_s390_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['fpregs']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['fpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['vxrs_low']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['vxrs_low']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['vxrs_high']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['vxrs_high']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['gs_cb']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['gs_cb']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['gs_bc']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['gs_bc']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['ri_cb']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['ri_cb']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_S390_REGS_ENTRY']._serialized_start=31
  _globals['_USER_S390_REGS_ENTRY']._serialized_end=157
  _globals['_USER_S390_VXRS_LOW_ENTRY']._serialized_start=159
  _globals['_USER_S390_VXRS_LOW_ENTRY']._serialized_end=199
  _globals['_USER_S390_VXRS_HIGH_ENTRY']._serialized_start=201
  _globals['_USER_S390_VXRS_HIGH_ENTRY']._serialized_end=242
  _globals['_USER_S390_FPREGS_ENTRY']._serialized_start=244
  _globals['_USER_S390_FPREGS_ENTRY']._serialized_end=295
  _globals['_USER_S390_GS_CB_ENTRY']._serialized_start=297
  _globals['_USER_S390_GS_CB_ENTRY']._serialized_end=334
  _globals['_USER_S390_RI_ENTRY']._serialized_start=336
  _globals['_USER_S390_RI_ENTRY']._serialized_end=385
  _globals['_THREAD_INFO_S390']._serialized_start=388
  _globals['_THREAD_INFO_S390']._serialized_end=772
# @@protoc_insertion_point(module_scope)
