# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tcp-stream.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'tcp-stream.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10tcp-stream.proto\x1a\nopts.proto\"e\n\x0etcp_opts_entry\x12\x0c\n\x04\x63ork\x18\x01 \x01(\x08\x12\x0f\n\x07nodelay\x18\x02 \x01(\x08\x12\x0f\n\x07keepcnt\x18\x03 \x01(\r\x12\x10\n\x08keepidle\x18\x04 \x01(\r\x12\x11\n\tkeepintvl\x18\x05 \x01(\r\"\xc8\x02\n\x10tcp_stream_entry\x12\x0f\n\x07inq_len\x18\x01 \x02(\r\x12\x0f\n\x07inq_seq\x18\x02 \x02(\r\x12\x10\n\x08outq_len\x18\x03 \x02(\r\x12\x10\n\x08outq_seq\x18\x04 \x02(\r\x12\x17\n\x08opt_mask\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x12\n\nsnd_wscale\x18\x06 \x02(\r\x12\x11\n\tmss_clamp\x18\x07 \x02(\r\x12\x12\n\nrcv_wscale\x18\x08 \x01(\r\x12\x11\n\ttimestamp\x18\t \x01(\r\x12\x0c\n\x04\x63ork\x18\n \x01(\x08\x12\x0f\n\x07nodelay\x18\x0b \x01(\x08\x12\x10\n\x08unsq_len\x18\x0c \x01(\r\x12\x0f\n\x07snd_wl1\x18\r \x01(\r\x12\x0f\n\x07snd_wnd\x18\x0e \x01(\r\x12\x12\n\nmax_window\x18\x0f \x01(\r\x12\x0f\n\x07rcv_wnd\x18\x10 \x01(\r\x12\x0f\n\x07rcv_wup\x18\x11 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tcp_stream_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TCP_STREAM_ENTRY'].fields_by_name['opt_mask']._loaded_options = None
  _globals['_TCP_STREAM_ENTRY'].fields_by_name['opt_mask']._serialized_options = b'\322?\002\010\001'
  _globals['_TCP_OPTS_ENTRY']._serialized_start=32
  _globals['_TCP_OPTS_ENTRY']._serialized_end=133
  _globals['_TCP_STREAM_ENTRY']._serialized_start=136
  _globals['_TCP_STREAM_ENTRY']._serialized_end=464
# @@protoc_insertion_point(module_scope)
