# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fsnotify.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'fsnotify.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fh_pb2 as fh__pb2
import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x66snotify.proto\x1a\nopts.proto\x1a\x08\x66h.proto\x1a\nfown.proto\"\x9e\x01\n\x10inotify_wd_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05i_ino\x18\x02 \x02(\x04\x12\x13\n\x04mask\x18\x03 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cignored_mask\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x14\n\x05s_dev\x18\x05 \x02(\rB\x05\xd2?\x02 \x01\x12\n\n\x02wd\x18\x06 \x02(\r\x12\x1b\n\x08\x66_handle\x18\x07 \x02(\x0b\x32\t.fh_entry\"p\n\x12inotify_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x14\n\x05\x66lags\x18\x02 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x19\n\x04\x66own\x18\x04 \x02(\x0b\x32\x0b.fown_entry\x12\x1d\n\x02wd\x18\x05 \x03(\x0b\x32\x11.inotify_wd_entry\"G\n\x19\x66\x61notify_inode_mark_entry\x12\r\n\x05i_ino\x18\x01 \x02(\x04\x12\x1b\n\x08\x66_handle\x18\x02 \x02(\x0b\x32\t.fh_entry\"9\n\x19\x66\x61notify_mount_mark_entry\x12\x0e\n\x06mnt_id\x18\x01 \x02(\r\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xea\x01\n\x13\x66\x61notify_mark_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x18\n\x04type\x18\x02 \x02(\x0e\x32\n.mark_type\x12\x15\n\x06mflags\x18\x03 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x13\n\x04mask\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cignored_mask\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x14\n\x05s_dev\x18\x06 \x02(\rB\x05\xd2?\x02 \x01\x12&\n\x02ie\x18\x07 \x01(\x0b\x32\x1a.fanotify_inode_mark_entry\x12&\n\x02me\x18\x08 \x01(\x0b\x32\x1a.fanotify_mount_mark_entry\"\xa6\x01\n\x13\x66\x61notify_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x14\n\x05\x66lags\x18\x02 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x19\n\x04\x66own\x18\x03 \x02(\x0b\x32\x0b.fown_entry\x12\x16\n\x07\x66\x61\x66lags\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x16\n\x07\x65vflags\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\"\n\x04mark\x18\x06 \x03(\x0b\x32\x14.fanotify_mark_entry*!\n\tmark_type\x12\t\n\x05INODE\x10\x01\x12\t\n\x05MOUNT\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsnotify_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['mask']._loaded_options = None
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['mask']._serialized_options = b'\322?\002\010\001'
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['ignored_mask']._loaded_options = None
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['ignored_mask']._serialized_options = b'\322?\002\010\001'
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['s_dev']._loaded_options = None
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['s_dev']._serialized_options = b'\322?\002 \001'
  _globals['_INOTIFY_FILE_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_INOTIFY_FILE_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['mflags']._loaded_options = None
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['mflags']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['mask']._loaded_options = None
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['mask']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['ignored_mask']._loaded_options = None
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['ignored_mask']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['s_dev']._loaded_options = None
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['s_dev']._serialized_options = b'\322?\002 \001'
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['faflags']._loaded_options = None
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['faflags']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['evflags']._loaded_options = None
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['evflags']._serialized_options = b'\322?\002\010\001'
  _globals['_MARK_TYPE']._serialized_start=865
  _globals['_MARK_TYPE']._serialized_end=898
  _globals['_INOTIFY_WD_ENTRY']._serialized_start=53
  _globals['_INOTIFY_WD_ENTRY']._serialized_end=211
  _globals['_INOTIFY_FILE_ENTRY']._serialized_start=213
  _globals['_INOTIFY_FILE_ENTRY']._serialized_end=325
  _globals['_FANOTIFY_INODE_MARK_ENTRY']._serialized_start=327
  _globals['_FANOTIFY_INODE_MARK_ENTRY']._serialized_end=398
  _globals['_FANOTIFY_MOUNT_MARK_ENTRY']._serialized_start=400
  _globals['_FANOTIFY_MOUNT_MARK_ENTRY']._serialized_end=457
  _globals['_FANOTIFY_MARK_ENTRY']._serialized_start=460
  _globals['_FANOTIFY_MARK_ENTRY']._serialized_end=694
  _globals['_FANOTIFY_FILE_ENTRY']._serialized_start=697
  _globals['_FANOTIFY_FILE_ENTRY']._serialized_end=863
# @@protoc_insertion_point(module_scope)
