# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sk-inet.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'sk-inet.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2
import tcp_stream_pb2 as tcp__stream__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rsk-inet.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\x1a\x10tcp-stream.proto\"^\n\x11ip_opts_raw_entry\x12\x0f\n\x07hdrincl\x18\x01 \x01(\x08\x12\x10\n\x08nodefrag\x18\x02 \x01(\x08\x12\x10\n\x08\x63hecksum\x18\x03 \x01(\x08\x12\x14\n\x0cicmpv_filter\x18\x04 \x03(\r\"m\n\rip_opts_entry\x12\x10\n\x08\x66reebind\x18\x01 \x01(\x08\x12\x1f\n\x03raw\x18\x04 \x01(\x0b\x32\x12.ip_opts_raw_entry\x12\x0f\n\x07pktinfo\x18\x05 \x01(\x08\x12\x0b\n\x03tos\x18\x06 \x01(\r\x12\x0b\n\x03ttl\x18\x07 \x01(\r\"\xd1\x03\n\rinet_sk_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03ino\x18\x02 \x02(\r\x12\x17\n\x06\x66\x61mily\x18\x03 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x15\n\x04type\x18\x04 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x16\n\x05proto\x18\x05 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x16\n\x05state\x18\x06 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x10\n\x08src_port\x18\x07 \x02(\r\x12\x10\n\x08\x64st_port\x18\x08 \x02(\r\x12\x14\n\x05\x66lags\x18\t \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07\x62\x61\x63klog\x18\n \x02(\r\x12\x17\n\x08src_addr\x18\x0b \x03(\rB\x05\xd2?\x02\x10\x01\x12\x17\n\x08\x64st_addr\x18\x0c \x03(\rB\x05\xd2?\x02\x10\x01\x12\x19\n\x04\x66own\x18\r \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\x0e \x02(\x0b\x32\x0e.sk_opts_entry\x12\x0e\n\x06v6only\x18\x0f \x01(\x08\x12\x1f\n\x07ip_opts\x18\x10 \x01(\x0b\x32\x0e.ip_opts_entry\x12\x0e\n\x06ifname\x18\x11 \x01(\t\x12\r\n\x05ns_id\x18\x12 \x01(\r\x12\x1e\n\x08shutdown\x18\x13 \x01(\x0e\x32\x0c.sk_shutdown\x12!\n\x08tcp_opts\x18\x14 \x01(\x0b\x32\x0f.tcp_opts_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sk_inet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['family']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['family']._serialized_options = b'\322?\0042\002sk'
  _globals['_INET_SK_ENTRY'].fields_by_name['type']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['type']._serialized_options = b'\322?\0042\002sk'
  _globals['_INET_SK_ENTRY'].fields_by_name['proto']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['proto']._serialized_options = b'\322?\0042\002sk'
  _globals['_INET_SK_ENTRY'].fields_by_name['state']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['state']._serialized_options = b'\322?\0042\002sk'
  _globals['_INET_SK_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_INET_SK_ENTRY'].fields_by_name['src_addr']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['src_addr']._serialized_options = b'\322?\002\020\001'
  _globals['_INET_SK_ENTRY'].fields_by_name['dst_addr']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['dst_addr']._serialized_options = b'\322?\002\020\001'
  _globals['_IP_OPTS_RAW_ENTRY']._serialized_start=74
  _globals['_IP_OPTS_RAW_ENTRY']._serialized_end=168
  _globals['_IP_OPTS_ENTRY']._serialized_start=170
  _globals['_IP_OPTS_ENTRY']._serialized_end=279
  _globals['_INET_SK_ENTRY']._serialized_start=282
  _globals['_INET_SK_ENTRY']._serialized_end=747
# @@protoc_insertion_point(module_scope)
