# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sysctl.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'sysctl.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csysctl.proto\"E\n\x0csysctl_entry\x12\x19\n\x04type\x18\x01 \x02(\x0e\x32\x0b.SysctlType\x12\x0c\n\x04iarg\x18\x02 \x01(\x05\x12\x0c\n\x04sarg\x18\x03 \x01(\t*%\n\nSysctlType\x12\x0b\n\x07\x43TL_STR\x10\x05\x12\n\n\x06\x43TL_32\x10\x06')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sysctl_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SYSCTLTYPE']._serialized_start=87
  _globals['_SYSCTLTYPE']._serialized_end=124
  _globals['_SYSCTL_ENTRY']._serialized_start=16
  _globals['_SYSCTL_ENTRY']._serialized_end=85
# @@protoc_insertion_point(module_scope)
