/* Autogenerated, don't edit */
#ifndef __ASM_CR_SYSCALL_CODES_H__
#define __ASM_CR_SYSCALL_CODES_H__
/* musl defines loff_t as off_t */
#ifndef loff_t
#define loff_t off_t
#endif
#include <compel/plugins/std/syscall-codes-64.h>

#ifndef  __NR32_restart_syscall
#define  __NR32_restart_syscall 0
#endif

#ifndef  __NR32_exit
#define  __NR32_exit 1
#endif

#ifndef  __NR32_read
#define  __NR32_read 3
#endif

#ifndef  __NR32_write
#define  __NR32_write 4
#endif

#ifndef  __NR32_open
#define  __NR32_open 5
#endif

#ifndef  __NR32_close
#define  __NR32_close 6
#endif

#ifndef  __NR32_unlink
#define  __NR32_unlink 10
#endif

#ifndef  __NR32_lseek
#define  __NR32_lseek 19
#endif

#ifndef  __NR32_getpid
#define  __NR32_getpid 20
#endif

#ifndef  __NR32_mount
#define  __NR32_mount 21
#endif

#ifndef  __NR32_ptrace
#define  __NR32_ptrace 26
#endif

#ifndef  __NR32_kill
#define  __NR32_kill 37
#endif

#ifndef  __NR32_mkdir
#define  __NR32_mkdir 39
#endif

#ifndef  __NR32_rmdir
#define  __NR32_rmdir 40
#endif

#ifndef  __NR32_brk
#define  __NR32_brk 45
#endif

#ifndef  __NR32_umount2
#define  __NR32_umount2 52
#endif

#ifndef  __NR32_ioctl
#define  __NR32_ioctl 54
#endif

#ifndef  __NR32_fcntl
#define  __NR32_fcntl 55
#endif

#ifndef  __NR32_umask
#define  __NR32_umask 60
#endif

#ifndef  __NR32_setrlimit
#define  __NR32_setrlimit 75
#endif

#ifndef  __NR32_gettimeofday
#define  __NR32_gettimeofday 78
#endif

#ifndef  __NR32_munmap
#define  __NR32_munmap 91
#endif

#ifndef  __NR32_setpriority
#define  __NR32_setpriority 97
#endif

#ifndef  __NR32_socketcall
#define  __NR32_socketcall 102
#endif

#ifndef  __NR32_setitimer
#define  __NR32_setitimer 104
#endif

#ifndef  __NR32_getitimer
#define  __NR32_getitimer 105
#endif

#ifndef  __NR32_wait4
#define  __NR32_wait4 114
#endif

#ifndef  __NR32_ipc
#define  __NR32_ipc 117
#endif

#ifndef  __NR32_clone
#define  __NR32_clone 120
#endif

#ifndef  __NR32_mprotect
#define  __NR32_mprotect 125
#endif

#ifndef  __NR32_getpgid
#define  __NR32_getpgid 132
#endif

#ifndef  __NR32_personality
#define  __NR32_personality 136
#endif

#ifndef  __NR32_flock
#define  __NR32_flock 143
#endif

#ifndef  __NR32_getsid
#define  __NR32_getsid 147
#endif

#ifndef  __NR32_sched_setscheduler
#define  __NR32_sched_setscheduler 156
#endif

#ifndef  __NR32_nanosleep
#define  __NR32_nanosleep 162
#endif

#ifndef  __NR32_mremap
#define  __NR32_mremap 163
#endif

#ifndef  __NR32_prctl
#define  __NR32_prctl 172
#endif

#ifndef  __NR32_rt_sigreturn
#define  __NR32_rt_sigreturn 173
#endif

#ifndef  __NR32_rt_sigaction
#define  __NR32_rt_sigaction 174
#endif

#ifndef  __NR32_rt_sigprocmask
#define  __NR32_rt_sigprocmask 175
#endif

#ifndef  __NR32_rt_sigqueueinfo
#define  __NR32_rt_sigqueueinfo 178
#endif

#ifndef  __NR32_pread64
#define  __NR32_pread64 180
#endif

#ifndef  __NR32_capget
#define  __NR32_capget 184
#endif

#ifndef  __NR32_capset
#define  __NR32_capset 185
#endif

#ifndef  __NR32_sigaltstack
#define  __NR32_sigaltstack 186
#endif

#ifndef  __NR32_mmap2
#define  __NR32_mmap2 192
#endif

#ifndef  __NR32_getgroups32
#define  __NR32_getgroups32 205
#endif

#ifndef  __NR32_setgroups32
#define  __NR32_setgroups32 206
#endif

#ifndef  __NR32_setresuid32
#define  __NR32_setresuid32 208
#endif

#ifndef  __NR32_getresuid32
#define  __NR32_getresuid32 209
#endif

#ifndef  __NR32_setresgid32
#define  __NR32_setresgid32 210
#endif

#ifndef  __NR32_getresgid32
#define  __NR32_getresgid32 211
#endif

#ifndef  __NR32_setfsuid32
#define  __NR32_setfsuid32 215
#endif

#ifndef  __NR32_setfsgid32
#define  __NR32_setfsgid32 216
#endif

#ifndef  __NR32_mincore
#define  __NR32_mincore 218
#endif

#ifndef  __NR32_madvise
#define  __NR32_madvise 219
#endif

#ifndef  __NR32_gettid
#define  __NR32_gettid 224
#endif

#ifndef  __NR32_futex
#define  __NR32_futex 240
#endif

#ifndef  __NR32_set_thread_area
#define  __NR32_set_thread_area 243
#endif

#ifndef  __NR32_get_thread_area
#define  __NR32_get_thread_area 244
#endif

#ifndef  __NR32_io_setup
#define  __NR32_io_setup 245
#endif

#ifndef  __NR32_io_getevents
#define  __NR32_io_getevents 247
#endif

#ifndef  __NR32_io_submit
#define  __NR32_io_submit 248
#endif

#ifndef  __NR32_exit_group
#define  __NR32_exit_group 252
#endif

#ifndef  __NR32_set_tid_address
#define  __NR32_set_tid_address 258
#endif

#ifndef  __NR32_timer_create
#define  __NR32_timer_create 259
#endif

#ifndef  __NR32_timer_settime
#define  __NR32_timer_settime 260
#endif

#ifndef  __NR32_timer_gettime
#define  __NR32_timer_gettime 261
#endif

#ifndef  __NR32_timer_getoverrun
#define  __NR32_timer_getoverrun 262
#endif

#ifndef  __NR32_timer_delete
#define  __NR32_timer_delete 263
#endif

#ifndef  __NR32_clock_gettime
#define  __NR32_clock_gettime 265
#endif

#ifndef  __NR32_waitid
#define  __NR32_waitid 284
#endif

#ifndef  __NR32_openat
#define  __NR32_openat 295
#endif

#ifndef  __NR32_readlinkat
#define  __NR32_readlinkat 305
#endif

#ifndef  __NR32_set_robust_list
#define  __NR32_set_robust_list 311
#endif

#ifndef  __NR32_get_robust_list
#define  __NR32_get_robust_list 312
#endif

#ifndef  __NR32_vmsplice
#define  __NR32_vmsplice 316
#endif

#ifndef  __NR32_signalfd
#define  __NR32_signalfd 321
#endif

#ifndef  __NR32_fallocate
#define  __NR32_fallocate 324
#endif

#ifndef  __NR32_timerfd_settime
#define  __NR32_timerfd_settime 325
#endif

#ifndef  __NR32_preadv
#define  __NR32_preadv 333
#endif

#ifndef  __NR32_rt_tgsigqueueinfo
#define  __NR32_rt_tgsigqueueinfo 335
#endif

#ifndef  __NR32_fanotify_init
#define  __NR32_fanotify_init 338
#endif

#ifndef  __NR32_fanotify_mark
#define  __NR32_fanotify_mark 339
#endif

#ifndef  __NR32_open_by_handle_at
#define  __NR32_open_by_handle_at 342
#endif

#ifndef  __NR32_setns
#define  __NR32_setns 346
#endif

#ifndef  __NR32_kcmp
#define  __NR32_kcmp 349
#endif

#ifndef  __NR32_seccomp
#define  __NR32_seccomp 354
#endif

#ifndef  __NR32_memfd_create
#define  __NR32_memfd_create 356
#endif

#ifndef  __NR32_userfaultfd
#define  __NR32_userfaultfd 374
#endif

#ifndef  __NR32_ppoll
#define  __NR32_ppoll 309
#endif

#ifndef  __NR32_open_tree
#define  __NR32_open_tree 428
#endif

#ifndef  __NR32_move_mount
#define  __NR32_move_mount 429
#endif

#ifndef  __NR32_fsopen
#define  __NR32_fsopen 430
#endif

#ifndef  __NR32_fsconfig
#define  __NR32_fsconfig 431
#endif

#ifndef  __NR32_fsmount
#define  __NR32_fsmount 432
#endif

#ifndef  __NR32_clone3
#define  __NR32_clone3 435
#endif

#ifndef  __NR32_close_range
#define  __NR32_close_range 436
#endif

#ifndef  __NR32_pidfd_open
#define  __NR32_pidfd_open 434
#endif

#ifndef  __NR32_openat2
#define  __NR32_openat2 437
#endif

#ifndef  __NR32_pidfd_getfd
#define  __NR32_pidfd_getfd 438
#endif

#ifndef  __NR32_rseq
#define  __NR32_rseq 386
#endif

#ifndef  __NR32_membarrier
#define  __NR32_membarrier 375
#endif
#endif /* __ASM_CR_SYSCALL_CODES_H__ */
