# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sk-unix.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'sk-unix.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rsk-unix.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\":\n\x10\x66ile_perms_entry\x12\x0c\n\x04mode\x18\x01 \x02(\r\x12\x0b\n\x03uid\x18\x02 \x02(\r\x12\x0b\n\x03gid\x18\x03 \x02(\r\"\x87\x03\n\runix_sk_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03ino\x18\x02 \x02(\r\x12\x15\n\x04type\x18\x03 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x16\n\x05state\x18\x04 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x14\n\x05\x66lags\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x15\n\x06uflags\x18\x06 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07\x62\x61\x63klog\x18\x07 \x02(\r\x12\x0c\n\x04peer\x18\x08 \x02(\r\x12\x19\n\x04\x66own\x18\t \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\n \x02(\x0b\x32\x0e.sk_opts_entry\x12\x1c\n\x04name\x18\x0b \x02(\x0c\x42\x0e\xd2?\x0b:\tunix_name\x12\x1e\n\x08shutdown\x18\x0c \x01(\x0e\x32\x0c.sk_shutdown\x12%\n\nfile_perms\x18\r \x01(\x0b\x32\x11.file_perms_entry\x12\x10\n\x08name_dir\x18\x0e \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x0f \x01(\x08\x12\r\n\x05ns_id\x18\x10 \x01(\r\x12\x12\n\x06mnt_id\x18\x11 \x01(\x11:\x02-1')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sk_unix_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['type']._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['type']._serialized_options = b'\322?\0042\002sk'
  _globals['_UNIX_SK_ENTRY'].fields_by_name['state']._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['state']._serialized_options = b'\322?\0042\002sk'
  _globals['_UNIX_SK_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_UNIX_SK_ENTRY'].fields_by_name['uflags']._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['uflags']._serialized_options = b'\322?\002\010\001'
  _globals['_UNIX_SK_ENTRY'].fields_by_name['name']._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['name']._serialized_options = b'\322?\013:\tunix_name'
  _globals['_FILE_PERMS_ENTRY']._serialized_start=56
  _globals['_FILE_PERMS_ENTRY']._serialized_end=114
  _globals['_UNIX_SK_ENTRY']._serialized_start=117
  _globals['_UNIX_SK_ENTRY']._serialized_end=508
# @@protoc_insertion_point(module_scope)
