/* Autogenerated, don't edit */
#ifndef __ASM_CR_SYSCALL_PROTO_H__
#define __ASM_CR_SYSCALL_PROTO_H__

#ifdef CONFIG_X86_32
#include <compel/plugins/std/syscall-32.h>
#else
#include <compel/plugins/std/syscall-64.h>
#endif /* CONFIG_X86_32 */

#endif /* __ASM_CR_SYSCALL_PROTO_H__ */
