# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: stats.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'stats.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bstats.proto\"\xe0\x02\n\x10\x64ump_stats_entry\x12\x15\n\rfreezing_time\x18\x01 \x02(\r\x12\x13\n\x0b\x66rozen_time\x18\x02 \x02(\r\x12\x14\n\x0cmemdump_time\x18\x03 \x02(\r\x12\x15\n\rmemwrite_time\x18\x04 \x02(\r\x12\x15\n\rpages_scanned\x18\x05 \x02(\x04\x12\x1c\n\x14pages_skipped_parent\x18\x06 \x02(\x04\x12\x15\n\rpages_written\x18\x07 \x02(\x04\x12\x15\n\rirmap_resolve\x18\x08 \x01(\r\x12\x12\n\npages_lazy\x18\t \x02(\x04\x12\x12\n\npage_pipes\x18\n \x01(\x04\x12\x16\n\x0epage_pipe_bufs\x18\x0b \x01(\x04\x12\x17\n\x0fshpages_scanned\x18\x0c \x01(\x04\x12\x1e\n\x16shpages_skipped_parent\x18\r \x01(\x04\x12\x17\n\x0fshpages_written\x18\x0e \x01(\x04\"\x8c\x01\n\x13restore_stats_entry\x12\x16\n\x0epages_compared\x18\x01 \x02(\x04\x12\x19\n\x11pages_skipped_cow\x18\x02 \x02(\x04\x12\x14\n\x0c\x66orking_time\x18\x03 \x02(\r\x12\x14\n\x0crestore_time\x18\x04 \x02(\r\x12\x16\n\x0epages_restored\x18\x05 \x01(\x04\"U\n\x0bstats_entry\x12\x1f\n\x04\x64ump\x18\x01 \x01(\x0b\x32\x11.dump_stats_entry\x12%\n\x07restore\x18\x02 \x01(\x0b\x32\x14.restore_stats_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stats_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DUMP_STATS_ENTRY']._serialized_start=16
  _globals['_DUMP_STATS_ENTRY']._serialized_end=368
  _globals['_RESTORE_STATS_ENTRY']._serialized_start=371
  _globals['_RESTORE_STATS_ENTRY']._serialized_end=511
  _globals['_STATS_ENTRY']._serialized_start=513
  _globals['_STATS_ENTRY']._serialized_end=598
# @@protoc_insertion_point(module_scope)
