# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ipc-sem.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'ipc-sem.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ipc_desc_pb2 as ipc__desc__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ripc-sem.proto\x1a\x0eipc-desc.proto\"=\n\ripc_sem_entry\x12\x1d\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x0f.ipc_desc_entry\x12\r\n\x05nsems\x18\x02 \x02(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ipc_sem_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IPC_SEM_ENTRY']._serialized_start=33
  _globals['_IPC_SEM_ENTRY']._serialized_end=94
# @@protoc_insertion_point(module_scope)
