# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eventpoll.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'eventpoll.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x65ventpoll.proto\x1a\nfown.proto\"u\n\x13\x65ventpoll_tfd_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03tfd\x18\x02 \x02(\r\x12\x0e\n\x06\x65vents\x18\x03 \x02(\r\x12\x0c\n\x04\x64\x61ta\x18\x04 \x02(\x04\x12\x0b\n\x03\x64\x65v\x18\x05 \x01(\r\x12\r\n\x05inode\x18\x06 \x01(\x04\x12\x0b\n\x03pos\x18\x07 \x01(\x04\"o\n\x14\x65ventpoll_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05\x66lags\x18\x02 \x02(\r\x12\x19\n\x04\x66own\x18\x03 \x02(\x0b\x32\x0b.fown_entry\x12!\n\x03tfd\x18\x04 \x03(\x0b\x32\x14.eventpoll_tfd_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eventpoll_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EVENTPOLL_TFD_ENTRY']._serialized_start=31
  _globals['_EVENTPOLL_TFD_ENTRY']._serialized_end=148
  _globals['_EVENTPOLL_FILE_ENTRY']._serialized_start=150
  _globals['_EVENTPOLL_FILE_ENTRY']._serialized_end=261
# @@protoc_insertion_point(module_scope)
