/* Autogenerated, don't edit */
#ifndef ASM_SYSCALL_CODES_H_64__
#define ASM_SYSCALL_CODES_H_64__

#ifndef  __NR_read
#define __NR_read 0
#endif

#ifndef  SYS_read
#define  SYS_read __NR_read
#endif

#ifndef  __NR_write
#define __NR_write 1
#endif

#ifndef  SYS_write
#define  SYS_write __NR_write
#endif

#ifndef  __NR_open
#define __NR_open 2
#endif

#ifndef  SYS_open
#define  SYS_open __NR_open
#endif

#ifndef  __NR_close
#define __NR_close 3
#endif

#ifndef  SYS_close
#define  SYS_close __NR_close
#endif

#ifndef  __NR_lseek
#define __NR_lseek 8
#endif

#ifndef  SYS_lseek
#define  SYS_lseek __NR_lseek
#endif

#ifndef  __NR_mmap
#define __NR_mmap 9
#endif

#ifndef  SYS_mmap
#define  SYS_mmap __NR_mmap
#endif

#ifndef  __NR_mprotect
#define __NR_mprotect 10
#endif

#ifndef  SYS_mprotect
#define  SYS_mprotect __NR_mprotect
#endif

#ifndef  __NR_munmap
#define __NR_munmap 11
#endif

#ifndef  SYS_munmap
#define  SYS_munmap __NR_munmap
#endif

#ifndef  __NR_brk
#define __NR_brk 12
#endif

#ifndef  SYS_brk
#define  SYS_brk __NR_brk
#endif

#ifndef  __NR_rt_sigaction
#define __NR_rt_sigaction 13
#endif

#ifndef  SYS_rt_sigaction
#define  SYS_rt_sigaction __NR_rt_sigaction
#endif

#ifndef  __NR_rt_sigprocmask
#define __NR_rt_sigprocmask 14
#endif

#ifndef  SYS_rt_sigprocmask
#define  SYS_rt_sigprocmask __NR_rt_sigprocmask
#endif

#ifndef  __NR_rt_sigreturn
#define __NR_rt_sigreturn 15
#endif

#ifndef  SYS_rt_sigreturn
#define  SYS_rt_sigreturn __NR_rt_sigreturn
#endif

#ifndef  __NR_ioctl
#define __NR_ioctl 16
#endif

#ifndef  SYS_ioctl
#define  SYS_ioctl __NR_ioctl
#endif

#ifndef  __NR_pread64
#define __NR_pread64 17
#endif

#ifndef  SYS_pread64
#define  SYS_pread64 __NR_pread64
#endif

#ifndef  __NR_mremap
#define __NR_mremap 25
#endif

#ifndef  SYS_mremap
#define  SYS_mremap __NR_mremap
#endif

#ifndef  __NR_mincore
#define __NR_mincore 27
#endif

#ifndef  SYS_mincore
#define  SYS_mincore __NR_mincore
#endif

#ifndef  __NR_madvise
#define __NR_madvise 28
#endif

#ifndef  SYS_madvise
#define  SYS_madvise __NR_madvise
#endif

#ifndef  __NR_shmat
#define __NR_shmat 30
#endif

#ifndef  SYS_shmat
#define  SYS_shmat __NR_shmat
#endif

#ifndef  __NR_dup2
#define __NR_dup2 33
#endif

#ifndef  SYS_dup2
#define  SYS_dup2 __NR_dup2
#endif

#ifndef  __NR_nanosleep
#define __NR_nanosleep 35
#endif

#ifndef  SYS_nanosleep
#define  SYS_nanosleep __NR_nanosleep
#endif

#ifndef  __NR_getitimer
#define __NR_getitimer 36
#endif

#ifndef  SYS_getitimer
#define  SYS_getitimer __NR_getitimer
#endif

#ifndef  __NR_setitimer
#define __NR_setitimer 38
#endif

#ifndef  SYS_setitimer
#define  SYS_setitimer __NR_setitimer
#endif

#ifndef  __NR_getpid
#define __NR_getpid 39
#endif

#ifndef  SYS_getpid
#define  SYS_getpid __NR_getpid
#endif

#ifndef  __NR_socket
#define __NR_socket 41
#endif

#ifndef  SYS_socket
#define  SYS_socket __NR_socket
#endif

#ifndef  __NR_connect
#define __NR_connect 42
#endif

#ifndef  SYS_connect
#define  SYS_connect __NR_connect
#endif

#ifndef  __NR_sendto
#define __NR_sendto 44
#endif

#ifndef  SYS_sendto
#define  SYS_sendto __NR_sendto
#endif

#ifndef  __NR_recvfrom
#define __NR_recvfrom 45
#endif

#ifndef  SYS_recvfrom
#define  SYS_recvfrom __NR_recvfrom
#endif

#ifndef  __NR_sendmsg
#define __NR_sendmsg 46
#endif

#ifndef  SYS_sendmsg
#define  SYS_sendmsg __NR_sendmsg
#endif

#ifndef  __NR_recvmsg
#define __NR_recvmsg 47
#endif

#ifndef  SYS_recvmsg
#define  SYS_recvmsg __NR_recvmsg
#endif

#ifndef  __NR_shutdown
#define __NR_shutdown 48
#endif

#ifndef  SYS_shutdown
#define  SYS_shutdown __NR_shutdown
#endif

#ifndef  __NR_bind
#define __NR_bind 49
#endif

#ifndef  SYS_bind
#define  SYS_bind __NR_bind
#endif

#ifndef  __NR_setsockopt
#define __NR_setsockopt 54
#endif

#ifndef  SYS_setsockopt
#define  SYS_setsockopt __NR_setsockopt
#endif

#ifndef  __NR_getsockopt
#define __NR_getsockopt 55
#endif

#ifndef  SYS_getsockopt
#define  SYS_getsockopt __NR_getsockopt
#endif

#ifndef  __NR_clone
#define __NR_clone 56
#endif

#ifndef  SYS_clone
#define  SYS_clone __NR_clone
#endif

#ifndef  __NR_exit
#define __NR_exit 60
#endif

#ifndef  SYS_exit
#define  SYS_exit __NR_exit
#endif

#ifndef  __NR_wait4
#define __NR_wait4 61
#endif

#ifndef  SYS_wait4
#define  SYS_wait4 __NR_wait4
#endif

#ifndef  __NR_kill
#define __NR_kill 62
#endif

#ifndef  SYS_kill
#define  SYS_kill __NR_kill
#endif

#ifndef  __NR_fcntl
#define __NR_fcntl 72
#endif

#ifndef  SYS_fcntl
#define  SYS_fcntl __NR_fcntl
#endif

#ifndef  __NR_flock
#define __NR_flock 73
#endif

#ifndef  SYS_flock
#define  SYS_flock __NR_flock
#endif

#ifndef  __NR_mkdir
#define __NR_mkdir 83
#endif

#ifndef  SYS_mkdir
#define  SYS_mkdir __NR_mkdir
#endif

#ifndef  __NR_rmdir
#define __NR_rmdir 84
#endif

#ifndef  SYS_rmdir
#define  SYS_rmdir __NR_rmdir
#endif

#ifndef  __NR_unlink
#define __NR_unlink 87
#endif

#ifndef  SYS_unlink
#define  SYS_unlink __NR_unlink
#endif

#ifndef  __NR_umask
#define __NR_umask 95
#endif

#ifndef  SYS_umask
#define  SYS_umask __NR_umask
#endif

#ifndef  __NR_gettimeofday
#define __NR_gettimeofday 96
#endif

#ifndef  SYS_gettimeofday
#define  SYS_gettimeofday __NR_gettimeofday
#endif

#ifndef  __NR_ptrace
#define __NR_ptrace 101
#endif

#ifndef  SYS_ptrace
#define  SYS_ptrace __NR_ptrace
#endif

#ifndef  __NR_getgroups
#define __NR_getgroups 115
#endif

#ifndef  SYS_getgroups
#define  SYS_getgroups __NR_getgroups
#endif

#ifndef  __NR_setgroups
#define __NR_setgroups 116
#endif

#ifndef  SYS_setgroups
#define  SYS_setgroups __NR_setgroups
#endif

#ifndef  __NR_setresuid
#define __NR_setresuid 117
#endif

#ifndef  SYS_setresuid
#define  SYS_setresuid __NR_setresuid
#endif

#ifndef  __NR_getresuid
#define __NR_getresuid 118
#endif

#ifndef  SYS_getresuid
#define  SYS_getresuid __NR_getresuid
#endif

#ifndef  __NR_setresgid
#define __NR_setresgid 119
#endif

#ifndef  SYS_setresgid
#define  SYS_setresgid __NR_setresgid
#endif

#ifndef  __NR_getresgid
#define __NR_getresgid 120
#endif

#ifndef  SYS_getresgid
#define  SYS_getresgid __NR_getresgid
#endif

#ifndef  __NR_getpgid
#define __NR_getpgid 121
#endif

#ifndef  SYS_getpgid
#define  SYS_getpgid __NR_getpgid
#endif

#ifndef  __NR_setfsuid
#define __NR_setfsuid 122
#endif

#ifndef  SYS_setfsuid
#define  SYS_setfsuid __NR_setfsuid
#endif

#ifndef  __NR_setfsgid
#define __NR_setfsgid 123
#endif

#ifndef  SYS_setfsgid
#define  SYS_setfsgid __NR_setfsgid
#endif

#ifndef  __NR_getsid
#define __NR_getsid 124
#endif

#ifndef  SYS_getsid
#define  SYS_getsid __NR_getsid
#endif

#ifndef  __NR_capget
#define __NR_capget 125
#endif

#ifndef  SYS_capget
#define  SYS_capget __NR_capget
#endif

#ifndef  __NR_capset
#define __NR_capset 126
#endif

#ifndef  SYS_capset
#define  SYS_capset __NR_capset
#endif

#ifndef  __NR_rt_sigqueueinfo
#define __NR_rt_sigqueueinfo 129
#endif

#ifndef  SYS_rt_sigqueueinfo
#define  SYS_rt_sigqueueinfo __NR_rt_sigqueueinfo
#endif

#ifndef  __NR_sigaltstack
#define __NR_sigaltstack 131
#endif

#ifndef  SYS_sigaltstack
#define  SYS_sigaltstack __NR_sigaltstack
#endif

#ifndef  __NR_personality
#define __NR_personality 135
#endif

#ifndef  SYS_personality
#define  SYS_personality __NR_personality
#endif

#ifndef  __NR_setpriority
#define __NR_setpriority 141
#endif

#ifndef  SYS_setpriority
#define  SYS_setpriority __NR_setpriority
#endif

#ifndef  __NR_sched_setscheduler
#define __NR_sched_setscheduler 144
#endif

#ifndef  SYS_sched_setscheduler
#define  SYS_sched_setscheduler __NR_sched_setscheduler
#endif

#ifndef  __NR_prctl
#define __NR_prctl 157
#endif

#ifndef  SYS_prctl
#define  SYS_prctl __NR_prctl
#endif

#ifndef  __NR_arch_prctl
#define __NR_arch_prctl 158
#endif

#ifndef  SYS_arch_prctl
#define  SYS_arch_prctl __NR_arch_prctl
#endif

#ifndef  __NR_setrlimit
#define __NR_setrlimit 160
#endif

#ifndef  SYS_setrlimit
#define  SYS_setrlimit __NR_setrlimit
#endif

#ifndef  __NR_mount
#define __NR_mount 165
#endif

#ifndef  SYS_mount
#define  SYS_mount __NR_mount
#endif

#ifndef  __NR_umount2
#define __NR_umount2 166
#endif

#ifndef  SYS_umount2
#define  SYS_umount2 __NR_umount2
#endif

#ifndef  __NR_gettid
#define __NR_gettid 186
#endif

#ifndef  SYS_gettid
#define  SYS_gettid __NR_gettid
#endif

#ifndef  __NR_futex
#define __NR_futex 202
#endif

#ifndef  SYS_futex
#define  SYS_futex __NR_futex
#endif

#ifndef  __NR_set_thread_area
#define __NR_set_thread_area 205
#endif

#ifndef  SYS_set_thread_area
#define  SYS_set_thread_area __NR_set_thread_area
#endif

#ifndef  __NR_io_setup
#define __NR_io_setup 206
#endif

#ifndef  SYS_io_setup
#define  SYS_io_setup __NR_io_setup
#endif

#ifndef  __NR_io_getevents
#define __NR_io_getevents 208
#endif

#ifndef  SYS_io_getevents
#define  SYS_io_getevents __NR_io_getevents
#endif

#ifndef  __NR_io_submit
#define __NR_io_submit 209
#endif

#ifndef  SYS_io_submit
#define  SYS_io_submit __NR_io_submit
#endif

#ifndef  __NR_get_thread_area
#define __NR_get_thread_area 211
#endif

#ifndef  SYS_get_thread_area
#define  SYS_get_thread_area __NR_get_thread_area
#endif

#ifndef  __NR_set_tid_address
#define __NR_set_tid_address 218
#endif

#ifndef  SYS_set_tid_address
#define  SYS_set_tid_address __NR_set_tid_address
#endif

#ifndef  __NR_restart_syscall
#define __NR_restart_syscall 219
#endif

#ifndef  SYS_restart_syscall
#define  SYS_restart_syscall __NR_restart_syscall
#endif

#ifndef  __NR_sys_timer_create
#define __NR_sys_timer_create 222
#endif

#ifndef  SYS_sys_timer_create
#define  SYS_sys_timer_create __NR_sys_timer_create
#endif

#ifndef  __NR_sys_timer_settime
#define __NR_sys_timer_settime 223
#endif

#ifndef  SYS_sys_timer_settime
#define  SYS_sys_timer_settime __NR_sys_timer_settime
#endif

#ifndef  __NR_sys_timer_gettime
#define __NR_sys_timer_gettime 224
#endif

#ifndef  SYS_sys_timer_gettime
#define  SYS_sys_timer_gettime __NR_sys_timer_gettime
#endif

#ifndef  __NR_sys_timer_getoverrun
#define __NR_sys_timer_getoverrun 225
#endif

#ifndef  SYS_sys_timer_getoverrun
#define  SYS_sys_timer_getoverrun __NR_sys_timer_getoverrun
#endif

#ifndef  __NR_sys_timer_delete
#define __NR_sys_timer_delete 226
#endif

#ifndef  SYS_sys_timer_delete
#define  SYS_sys_timer_delete __NR_sys_timer_delete
#endif

#ifndef  __NR_clock_gettime
#define __NR_clock_gettime 228
#endif

#ifndef  SYS_clock_gettime
#define  SYS_clock_gettime __NR_clock_gettime
#endif

#ifndef  __NR_exit_group
#define __NR_exit_group 231
#endif

#ifndef  SYS_exit_group
#define  SYS_exit_group __NR_exit_group
#endif

#ifndef  __NR_openat
#define __NR_openat 257
#endif

#ifndef  SYS_openat
#define  SYS_openat __NR_openat
#endif

#ifndef  __NR_waitid
#define __NR_waitid 247
#endif

#ifndef  SYS_waitid
#define  SYS_waitid __NR_waitid
#endif

#ifndef  __NR_readlinkat
#define __NR_readlinkat 267
#endif

#ifndef  SYS_readlinkat
#define  SYS_readlinkat __NR_readlinkat
#endif

#ifndef  __NR_set_robust_list
#define __NR_set_robust_list 273
#endif

#ifndef  SYS_set_robust_list
#define  SYS_set_robust_list __NR_set_robust_list
#endif

#ifndef  __NR_get_robust_list
#define __NR_get_robust_list 274
#endif

#ifndef  SYS_get_robust_list
#define  SYS_get_robust_list __NR_get_robust_list
#endif

#ifndef  __NR_seccomp
#define __NR_seccomp 317
#endif

#ifndef  SYS_seccomp
#define  SYS_seccomp __NR_seccomp
#endif

#ifndef  __NR_vmsplice
#define __NR_vmsplice 278
#endif

#ifndef  SYS_vmsplice
#define  SYS_vmsplice __NR_vmsplice
#endif

#ifndef  __NR_fallocate
#define __NR_fallocate 285
#endif

#ifndef  SYS_fallocate
#define  SYS_fallocate __NR_fallocate
#endif

#ifndef  __NR_timerfd_settime
#define __NR_timerfd_settime 286
#endif

#ifndef  SYS_timerfd_settime
#define  SYS_timerfd_settime __NR_timerfd_settime
#endif

#ifndef  __NR_signalfd4
#define __NR_signalfd4 289
#endif

#ifndef  SYS_signalfd4
#define  SYS_signalfd4 __NR_signalfd4
#endif

#ifndef  __NR_preadv
#define __NR_preadv 295
#endif

#ifndef  SYS_preadv
#define  SYS_preadv __NR_preadv
#endif

#ifndef  __NR_rt_tgsigqueueinfo
#define __NR_rt_tgsigqueueinfo 297
#endif

#ifndef  SYS_rt_tgsigqueueinfo
#define  SYS_rt_tgsigqueueinfo __NR_rt_tgsigqueueinfo
#endif

#ifndef  __NR_fanotify_init
#define __NR_fanotify_init 300
#endif

#ifndef  SYS_fanotify_init
#define  SYS_fanotify_init __NR_fanotify_init
#endif

#ifndef  __NR_fanotify_mark
#define __NR_fanotify_mark 301
#endif

#ifndef  SYS_fanotify_mark
#define  SYS_fanotify_mark __NR_fanotify_mark
#endif

#ifndef  __NR_open_by_handle_at
#define __NR_open_by_handle_at 304
#endif

#ifndef  SYS_open_by_handle_at
#define  SYS_open_by_handle_at __NR_open_by_handle_at
#endif

#ifndef  __NR_setns
#define __NR_setns 308
#endif

#ifndef  SYS_setns
#define  SYS_setns __NR_setns
#endif

#ifndef  __NR_kcmp
#define __NR_kcmp 312
#endif

#ifndef  SYS_kcmp
#define  SYS_kcmp __NR_kcmp
#endif

#ifndef  __NR_memfd_create
#define __NR_memfd_create 319
#endif

#ifndef  SYS_memfd_create
#define  SYS_memfd_create __NR_memfd_create
#endif

#ifndef  __NR_userfaultfd
#define __NR_userfaultfd 323
#endif

#ifndef  SYS_userfaultfd
#define  SYS_userfaultfd __NR_userfaultfd
#endif

#ifndef  __NR_ppoll
#define __NR_ppoll 271
#endif

#ifndef  SYS_ppoll
#define  SYS_ppoll __NR_ppoll
#endif

#ifndef  __NR_open_tree
#define __NR_open_tree 428
#endif

#ifndef  SYS_open_tree
#define  SYS_open_tree __NR_open_tree
#endif

#ifndef  __NR_move_mount
#define __NR_move_mount 429
#endif

#ifndef  SYS_move_mount
#define  SYS_move_mount __NR_move_mount
#endif

#ifndef  __NR_fsopen
#define __NR_fsopen 430
#endif

#ifndef  SYS_fsopen
#define  SYS_fsopen __NR_fsopen
#endif

#ifndef  __NR_fsconfig
#define __NR_fsconfig 431
#endif

#ifndef  SYS_fsconfig
#define  SYS_fsconfig __NR_fsconfig
#endif

#ifndef  __NR_fsmount
#define __NR_fsmount 432
#endif

#ifndef  SYS_fsmount
#define  SYS_fsmount __NR_fsmount
#endif

#ifndef  __NR_clone3
#define __NR_clone3 435
#endif

#ifndef  SYS_clone3
#define  SYS_clone3 __NR_clone3
#endif

#ifndef  __NR_close_range
#define __NR_close_range 436
#endif

#ifndef  SYS_close_range
#define  SYS_close_range __NR_close_range
#endif

#ifndef  __NR_pidfd_open
#define __NR_pidfd_open 434
#endif

#ifndef  SYS_pidfd_open
#define  SYS_pidfd_open __NR_pidfd_open
#endif

#ifndef  __NR_openat2
#define __NR_openat2 437
#endif

#ifndef  SYS_openat2
#define  SYS_openat2 __NR_openat2
#endif

#ifndef  __NR_pidfd_getfd
#define __NR_pidfd_getfd 438
#endif

#ifndef  SYS_pidfd_getfd
#define  SYS_pidfd_getfd __NR_pidfd_getfd
#endif

#ifndef  __NR_rseq
#define __NR_rseq 334
#endif

#ifndef  SYS_rseq
#define  SYS_rseq __NR_rseq
#endif

#ifndef  __NR_membarrier
#define __NR_membarrier 324
#endif

#ifndef  SYS_membarrier
#define  SYS_membarrier __NR_membarrier
#endif

#ifndef  __NR_map_shadow_stack
#define __NR_map_shadow_stack 453
#endif

#ifndef  SYS_map_shadow_stack
#define  SYS_map_shadow_stack __NR_map_shadow_stack
#endif
#endif /* ASM_SYSCALL_CODES_H_64__ */
