# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apparmor.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'apparmor.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x61pparmor.proto\"\'\n\taa_policy\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04\x62lob\x18\x02 \x02(\x0c\"]\n\x0c\x61\x61_namespace\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x1c\n\x08policies\x18\x02 \x03(\x0b\x32\n.aa_policy\x12!\n\nnamespaces\x18\x03 \x03(\x0b\x32\r.aa_namespace\"3\n\x0e\x61pparmor_entry\x12!\n\nnamespaces\x18\x01 \x03(\x0b\x32\r.aa_namespace')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apparmor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AA_POLICY']._serialized_start=18
  _globals['_AA_POLICY']._serialized_end=57
  _globals['_AA_NAMESPACE']._serialized_start=59
  _globals['_AA_NAMESPACE']._serialized_end=152
  _globals['_APPARMOR_ENTRY']._serialized_start=154
  _globals['_APPARMOR_ENTRY']._serialized_end=205
# @@protoc_insertion_point(module_scope)
