# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-loongarch64.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'core-loongarch64.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63ore-loongarch64.proto\x1a\nopts.proto\"9\n\x1duser_loongarch64_gpregs_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\x12\n\n\x02pc\x18\x02 \x02(\x04\"H\n\x1duser_loongarch64_fpregs_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\x12\x0b\n\x03\x66\x63\x63\x18\x02 \x02(\x04\x12\x0c\n\x04\x66\x63sr\x18\x03 \x02(\r\"\xb3\x01\n\x17thread_info_loongarch64\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0b\n\x03tls\x18\x02 \x02(\x04\x12\x35\n\x06gpregs\x18\x03 \x02(\x0b\x32\x1e.user_loongarch64_gpregs_entryB\x05\xd2?\x02\x08\x01\x12\x35\n\x06\x66pregs\x18\x04 \x02(\x0b\x32\x1e.user_loongarch64_fpregs_entryB\x05\xd2?\x02\x08\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_loongarch64_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['fpregs']._loaded_options = None
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['fpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_LOONGARCH64_GPREGS_ENTRY']._serialized_start=38
  _globals['_USER_LOONGARCH64_GPREGS_ENTRY']._serialized_end=95
  _globals['_USER_LOONGARCH64_FPREGS_ENTRY']._serialized_start=97
  _globals['_USER_LOONGARCH64_FPREGS_ENTRY']._serialized_end=169
  _globals['_THREAD_INFO_LOONGARCH64']._serialized_start=172
  _globals['_THREAD_INFO_LOONGARCH64']._serialized_end=351
# @@protoc_insertion_point(module_scope)
