# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-x86.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'core-x86.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63ore-x86.proto\x1a\nopts.proto\"\x9c\x03\n\x13user_x86_regs_entry\x12\x0b\n\x03r15\x18\x01 \x02(\x04\x12\x0b\n\x03r14\x18\x02 \x02(\x04\x12\x0b\n\x03r13\x18\x03 \x02(\x04\x12\x0b\n\x03r12\x18\x04 \x02(\x04\x12\n\n\x02\x62p\x18\x05 \x02(\x04\x12\n\n\x02\x62x\x18\x06 \x02(\x04\x12\x0b\n\x03r11\x18\x07 \x02(\x04\x12\x0b\n\x03r10\x18\x08 \x02(\x04\x12\n\n\x02r9\x18\t \x02(\x04\x12\n\n\x02r8\x18\n \x02(\x04\x12\n\n\x02\x61x\x18\x0b \x02(\x04\x12\n\n\x02\x63x\x18\x0c \x02(\x04\x12\n\n\x02\x64x\x18\r \x02(\x04\x12\n\n\x02si\x18\x0e \x02(\x04\x12\n\n\x02\x64i\x18\x0f \x02(\x04\x12\x0f\n\x07orig_ax\x18\x10 \x02(\x04\x12\n\n\x02ip\x18\x11 \x02(\x04\x12\n\n\x02\x63s\x18\x12 \x02(\x04\x12\r\n\x05\x66lags\x18\x13 \x02(\x04\x12\n\n\x02sp\x18\x14 \x02(\x04\x12\n\n\x02ss\x18\x15 \x02(\x04\x12\x0f\n\x07\x66s_base\x18\x16 \x02(\x04\x12\x0f\n\x07gs_base\x18\x17 \x02(\x04\x12\n\n\x02\x64s\x18\x18 \x02(\x04\x12\n\n\x02\x65s\x18\x19 \x02(\x04\x12\n\n\x02\x66s\x18\x1a \x02(\x04\x12\n\n\x02gs\x18\x1b \x02(\x04\x12)\n\x04mode\x18\x1c \x01(\x0e\x32\x13.user_x86_regs_mode:\x06NATIVE\"<\n\x12user_x86_cet_entry\x12\x12\n\x03\x63\x65t\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x12\n\x03ssp\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\"\xd2\x01\n\x14user_x86_xsave_entry\x12\x11\n\txstate_bv\x18\x01 \x02(\x04\x12\x12\n\nymmh_space\x18\x02 \x03(\r\x12\x14\n\x0c\x62ndreg_state\x18\x03 \x03(\x04\x12\x14\n\x0c\x62ndcsr_state\x18\x04 \x03(\x04\x12\x12\n\nopmask_reg\x18\x05 \x03(\x04\x12\x11\n\tzmm_upper\x18\x06 \x03(\x04\x12\x10\n\x08hi16_zmm\x18\x07 \x03(\x04\x12\x0c\n\x04pkru\x18\x08 \x03(\r\x12 \n\x03\x63\x65t\x18\t \x01(\x0b\x32\x13.user_x86_cet_entry\"\xe4\x01\n\x15user_x86_fpregs_entry\x12\x0b\n\x03\x63wd\x18\x01 \x02(\r\x12\x0b\n\x03swd\x18\x02 \x02(\r\x12\x0b\n\x03twd\x18\x03 \x02(\r\x12\x0b\n\x03\x66op\x18\x04 \x02(\r\x12\x0b\n\x03rip\x18\x05 \x02(\x04\x12\x0b\n\x03rdp\x18\x06 \x02(\x04\x12\r\n\x05mxcsr\x18\x07 \x02(\r\x12\x12\n\nmxcsr_mask\x18\x08 \x02(\r\x12\x10\n\x08st_space\x18\t \x03(\r\x12\x11\n\txmm_space\x18\n \x03(\r\x12\x0f\n\x07padding\x18\x0b \x03(\r\x12$\n\x05xsave\x18\r \x01(\x0b\x32\x15.user_x86_xsave_entry\"\xe5\x01\n\x0buser_desc_t\x12\x14\n\x0c\x65ntry_number\x18\x01 \x02(\r\x12\x11\n\tbase_addr\x18\x02 \x02(\r\x12\r\n\x05limit\x18\x03 \x02(\r\x12\x11\n\tseg_32bit\x18\x04 \x02(\x08\x12\x12\n\ncontents_h\x18\x05 \x02(\x08\x12\x12\n\ncontents_l\x18\x06 \x02(\x08\x12\x1c\n\x0eread_exec_only\x18\x07 \x02(\x08:\x04true\x12\x16\n\x0elimit_in_pages\x18\x08 \x02(\x08\x12\x1d\n\x0fseg_not_present\x18\t \x02(\x08:\x04true\x12\x0e\n\x06usable\x18\n \x02(\x08\"\xa0\x01\n\x0fthread_info_x86\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12+\n\x06gpregs\x18\x02 \x02(\x0b\x32\x14.user_x86_regs_entryB\x05\xd2?\x02\x08\x01\x12&\n\x06\x66pregs\x18\x03 \x02(\x0b\x32\x16.user_x86_fpregs_entry\x12\x19\n\x03tls\x18\x04 \x03(\x0b\x32\x0c.user_desc_t*,\n\x12user_x86_regs_mode\x12\n\n\x06NATIVE\x10\x01\x12\n\n\x06\x43OMPAT\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_x86_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_USER_X86_CET_ENTRY'].fields_by_name['cet']._loaded_options = None
  _globals['_USER_X86_CET_ENTRY'].fields_by_name['cet']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_X86_CET_ENTRY'].fields_by_name['ssp']._loaded_options = None
  _globals['_USER_X86_CET_ENTRY'].fields_by_name['ssp']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_X86'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_X86'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_X86'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_X86'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_X86_REGS_MODE']._serialized_start=1346
  _globals['_USER_X86_REGS_MODE']._serialized_end=1390
  _globals['_USER_X86_REGS_ENTRY']._serialized_start=31
  _globals['_USER_X86_REGS_ENTRY']._serialized_end=443
  _globals['_USER_X86_CET_ENTRY']._serialized_start=445
  _globals['_USER_X86_CET_ENTRY']._serialized_end=505
  _globals['_USER_X86_XSAVE_ENTRY']._serialized_start=508
  _globals['_USER_X86_XSAVE_ENTRY']._serialized_end=718
  _globals['_USER_X86_FPREGS_ENTRY']._serialized_start=721
  _globals['_USER_X86_FPREGS_ENTRY']._serialized_end=949
  _globals['_USER_DESC_T']._serialized_start=952
  _globals['_USER_DESC_T']._serialized_end=1181
  _globals['_THREAD_INFO_X86']._serialized_start=1184
  _globals['_THREAD_INFO_X86']._serialized_end=1344
# @@protoc_insertion_point(module_scope)
