# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: remap-file-path.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'remap-file-path.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15remap-file-path.proto\"[\n\x15remap_file_path_entry\x12\x0f\n\x07orig_id\x18\x01 \x02(\r\x12\x10\n\x08remap_id\x18\x02 \x02(\r\x12\x1f\n\nremap_type\x18\x03 \x01(\x0e\x32\x0b.remap_type*/\n\nremap_type\x12\n\n\x06LINKED\x10\x00\x12\t\n\x05GHOST\x10\x01\x12\n\n\x06PROCFS\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'remap_file_path_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REMAP_TYPE']._serialized_start=118
  _globals['_REMAP_TYPE']._serialized_end=165
  _globals['_REMAP_FILE_PATH_ENTRY']._serialized_start=25
  _globals['_REMAP_FILE_PATH_ENTRY']._serialized_end=116
# @@protoc_insertion_point(module_scope)
