# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ipc-var.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'ipc-var.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ripc-var.proto\"\xfd\x02\n\ripc_var_entry\x12\x10\n\x08sem_ctls\x18\x01 \x03(\r\x12\x12\n\nmsg_ctlmax\x18\x02 \x02(\r\x12\x12\n\nmsg_ctlmnb\x18\x03 \x02(\r\x12\x12\n\nmsg_ctlmni\x18\x04 \x02(\r\x12\x13\n\x0b\x61uto_msgmni\x18\x05 \x02(\r\x12\x12\n\nshm_ctlmax\x18\x06 \x02(\x04\x12\x12\n\nshm_ctlall\x18\x07 \x02(\x04\x12\x12\n\nshm_ctlmni\x18\x08 \x02(\r\x12\x17\n\x0fshm_rmid_forced\x18\t \x02(\r\x12\x15\n\rmq_queues_max\x18\n \x02(\r\x12\x12\n\nmq_msg_max\x18\x0b \x02(\r\x12\x16\n\x0emq_msgsize_max\x18\x0c \x02(\r\x12\x16\n\x0emq_msg_default\x18\r \x01(\r\x12\x1a\n\x12mq_msgsize_default\x18\x0e \x01(\r\x12\x13\n\x0bmsg_next_id\x18\x0f \x01(\r\x12\x13\n\x0bsem_next_id\x18\x10 \x01(\r\x12\x13\n\x0bshm_next_id\x18\x11 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ipc_var_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IPC_VAR_ENTRY']._serialized_start=18
  _globals['_IPC_VAR_ENTRY']._serialized_end=399
# @@protoc_insertion_point(module_scope)
