# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: pagemap.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'pagemap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rpagemap.proto\x1a\nopts.proto\" \n\x0cpagemap_head\x12\x10\n\x08pages_id\x18\x01 \x02(\r\"\x83\x01\n\rpagemap_entry\x12\x14\n\x05vaddr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x17\n\x0f\x63ompat_nr_pages\x18\x02 \x02(\r\x12\x11\n\tin_parent\x18\x03 \x01(\x08\x12\x1e\n\x05\x66lags\x18\x04 \x01(\rB\x0f\xd2?\x0c\x1a\npmap.flags\x12\x10\n\x08nr_pages\x18\x05 \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pagemap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PAGEMAP_ENTRY'].fields_by_name['vaddr']._loaded_options = None
  _globals['_PAGEMAP_ENTRY'].fields_by_name['vaddr']._serialized_options = b'\322?\002\010\001'
  _globals['_PAGEMAP_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_PAGEMAP_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\014\032\npmap.flags'
  _globals['_PAGEMAP_HEAD']._serialized_start=29
  _globals['_PAGEMAP_HEAD']._serialized_end=61
  _globals['_PAGEMAP_ENTRY']._serialized_start=64
  _globals['_PAGEMAP_ENTRY']._serialized_end=195
# @@protoc_insertion_point(module_scope)
