# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: binfmt-misc.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'binfmt-misc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x62infmt-misc.proto\"\x96\x01\n\x11\x62infmt_misc_entry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x02(\x08\x12\x13\n\x0binterpreter\x18\x03 \x02(\t\x12\r\n\x05\x66lags\x18\x04 \x01(\t\x12\x11\n\textension\x18\x05 \x01(\t\x12\r\n\x05magic\x18\x06 \x01(\t\x12\x0c\n\x04mask\x18\x07 \x01(\t\x12\x0e\n\x06offset\x18\x08 \x01(\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'binfmt_misc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BINFMT_MISC_ENTRY']._serialized_start=22
  _globals['_BINFMT_MISC_ENTRY']._serialized_end=172
# @@protoc_insertion_point(module_scope)
