# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: timerfd.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'timerfd.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rtimerfd.proto\x1a\nopts.proto\x1a\nfown.proto\"\xc4\x01\n\rtimerfd_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x14\n\x05\x66lags\x18\x02 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x19\n\x04\x66own\x18\x03 \x02(\x0b\x32\x0b.fown_entry\x12\x0f\n\x07\x63lockid\x18\x04 \x02(\r\x12\r\n\x05ticks\x18\x05 \x02(\x04\x12\x1c\n\rsettime_flags\x18\x06 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0c\n\x04vsec\x18\x07 \x02(\x04\x12\r\n\x05vnsec\x18\x08 \x02(\x04\x12\x0c\n\x04isec\x18\t \x02(\x04\x12\r\n\x05insec\x18\n \x02(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'timerfd_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TIMERFD_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_TIMERFD_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_TIMERFD_ENTRY'].fields_by_name['settime_flags']._loaded_options = None
  _globals['_TIMERFD_ENTRY'].fields_by_name['settime_flags']._serialized_options = b'\322?\002\010\001'
  _globals['_TIMERFD_ENTRY']._serialized_start=42
  _globals['_TIMERFD_ENTRY']._serialized_end=238
# @@protoc_insertion_point(module_scope)
