# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sit.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'sit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tsit.proto\x1a\nopts.proto\"\xc9\x02\n\tsit_entry\x12\x0c\n\x04link\x18\x01 \x01(\r\x12\x14\n\x05local\x18\x02 \x03(\rB\x05\xd2?\x02\x10\x01\x12\x15\n\x06remote\x18\x03 \x03(\rB\x05\xd2?\x02\x10\x01\x12\x0b\n\x03ttl\x18\x04 \x01(\r\x12\x0b\n\x03tos\x18\x05 \x01(\r\x12\x10\n\x08pmtudisc\x18\x06 \x01(\x08\x12\r\n\x05proto\x18\x07 \x01(\r\x12\r\n\x05\x66lags\x18\x08 \x01(\r\x12\x12\n\nencap_type\x18\t \x01(\r\x12\x13\n\x0b\x65ncap_flags\x18\n \x01(\r\x12\x13\n\x0b\x65ncap_sport\x18\x0b \x01(\r\x12\x13\n\x0b\x65ncap_dport\x18\x0c \x01(\r\x12\x14\n\x0crd_prefixlen\x18\r \x01(\r\x12\x18\n\trd_prefix\x18\x0e \x03(\rB\x05\xd2?\x02\x10\x01\x12\x17\n\x0frelay_prefixlen\x18\x0f \x01(\r\x12\x1b\n\x0crelay_prefix\x18\x10 \x03(\rB\x05\xd2?\x02\x10\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SIT_ENTRY'].fields_by_name['local']._loaded_options = None
  _globals['_SIT_ENTRY'].fields_by_name['local']._serialized_options = b'\322?\002\020\001'
  _globals['_SIT_ENTRY'].fields_by_name['remote']._loaded_options = None
  _globals['_SIT_ENTRY'].fields_by_name['remote']._serialized_options = b'\322?\002\020\001'
  _globals['_SIT_ENTRY'].fields_by_name['rd_prefix']._loaded_options = None
  _globals['_SIT_ENTRY'].fields_by_name['rd_prefix']._serialized_options = b'\322?\002\020\001'
  _globals['_SIT_ENTRY'].fields_by_name['relay_prefix']._loaded_options = None
  _globals['_SIT_ENTRY'].fields_by_name['relay_prefix']._serialized_options = b'\322?\002\020\001'
  _globals['_SIT_ENTRY']._serialized_start=26
  _globals['_SIT_ENTRY']._serialized_end=355
# @@protoc_insertion_point(module_scope)
