# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: opts.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'opts.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nopts.proto\x1a google/protobuf/descriptor.proto\"m\n\tCRIU_Opts\x12\x0b\n\x03hex\x18\x01 \x01(\x08\x12\r\n\x05ipadd\x18\x02 \x01(\x08\x12\r\n\x05\x66lags\x18\x03 \x01(\t\x12\x0b\n\x03\x64\x65v\x18\x04 \x01(\x08\x12\x0c\n\x04odev\x18\x05 \x01(\x08\x12\x0c\n\x04\x64ict\x18\x06 \x01(\t\x12\x0c\n\x04\x63onv\x18\x07 \x01(\t:8\n\x04\x63riu\x12\x1d.google.protobuf.FieldOptions\x18\xfa\x07 \x01(\x0b\x32\n.CRIU_Opts')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CRIU_OPTS']._serialized_start=48
  _globals['_CRIU_OPTS']._serialized_end=157
# @@protoc_insertion_point(module_scope)
