# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: userns.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'userns.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cuserns.proto\"C\n\x0euid_gid_extent\x12\r\n\x05\x66irst\x18\x01 \x02(\r\x12\x13\n\x0blower_first\x18\x02 \x02(\r\x12\r\n\x05\x63ount\x18\x03 \x02(\r\"R\n\x0cuserns_entry\x12 \n\x07uid_map\x18\x01 \x03(\x0b\x32\x0f.uid_gid_extent\x12 \n\x07gid_map\x18\x02 \x03(\x0b\x32\x0f.uid_gid_extent')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'userns_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UID_GID_EXTENT']._serialized_start=16
  _globals['_UID_GID_EXTENT']._serialized_end=83
  _globals['_USERNS_ENTRY']._serialized_start=85
  _globals['_USERNS_ENTRY']._serialized_end=167
# @@protoc_insertion_point(module_scope)
