# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cgroup.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'cgroup.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63group.proto\"6\n\x0c\x63group_perms\x12\x0c\n\x04mode\x18\x01 \x02(\r\x12\x0b\n\x03uid\x18\x02 \x02(\r\x12\x0b\n\x03gid\x18\x03 \x02(\r\"N\n\x11\x63group_prop_entry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\x12\x1c\n\x05perms\x18\x03 \x01(\x0b\x32\r.cgroup_perms\"\x93\x01\n\x10\x63group_dir_entry\x12\x10\n\x08\x64ir_name\x18\x01 \x02(\t\x12#\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x11.cgroup_dir_entry\x12&\n\nproperties\x18\x03 \x03(\x0b\x32\x12.cgroup_prop_entry\x12 \n\tdir_perms\x18\x04 \x01(\x0b\x32\r.cgroup_perms\"[\n\x13\x63g_controller_entry\x12\x0e\n\x06\x63names\x18\x01 \x03(\t\x12\x1f\n\x04\x64irs\x18\x02 \x03(\x0b\x32\x11.cgroup_dir_entry\x12\x13\n\x0bis_threaded\x18\x03 \x01(\x08\"B\n\x0f\x63g_member_entry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12\x13\n\x0b\x63gns_prefix\x18\x03 \x01(\r\":\n\x0c\x63g_set_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x1e\n\x04\x63tls\x18\x02 \x03(\x0b\x32\x10.cg_member_entry\"V\n\x0c\x63group_entry\x12\x1b\n\x04sets\x18\x01 \x03(\x0b\x32\r.cg_set_entry\x12)\n\x0b\x63ontrollers\x18\x02 \x03(\x0b\x32\x14.cg_controller_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cgroup_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CGROUP_PERMS']._serialized_start=16
  _globals['_CGROUP_PERMS']._serialized_end=70
  _globals['_CGROUP_PROP_ENTRY']._serialized_start=72
  _globals['_CGROUP_PROP_ENTRY']._serialized_end=150
  _globals['_CGROUP_DIR_ENTRY']._serialized_start=153
  _globals['_CGROUP_DIR_ENTRY']._serialized_end=300
  _globals['_CG_CONTROLLER_ENTRY']._serialized_start=302
  _globals['_CG_CONTROLLER_ENTRY']._serialized_end=393
  _globals['_CG_MEMBER_ENTRY']._serialized_start=395
  _globals['_CG_MEMBER_ENTRY']._serialized_end=461
  _globals['_CG_SET_ENTRY']._serialized_start=463
  _globals['_CG_SET_ENTRY']._serialized_end=521
  _globals['_CGROUP_ENTRY']._serialized_start=523
  _globals['_CGROUP_ENTRY']._serialized_end=609
# @@protoc_insertion_point(module_scope)
